@@ -1,5 +1,5 @@
 package DBIx::Lite::ResultSet;
-$DBIx::Lite::ResultSet::VERSION = '0.27';
+$DBIx::Lite::ResultSet::VERSION = '0.28';
 use strict;
 use warnings;
 
@@ -110,6 +110,14 @@ sub search {
     $new_self;
 }
 
+sub clear_search {
+    my $self = shift;
+    
+    my $new_self = $self->_clone;
+    @{$new_self->{where}} = ();
+    $new_self;
+}
+
 sub find {
     my $self = shift;
     my ($where) = @_;
@@ -544,6 +552,14 @@ sub _join {
     $new_self;
 }
 
+sub clear_joins {
+    my $self = shift;
+    
+    my $new_self = $self->_clone;
+    @{$new_self->{joins}} = ();
+    $new_self;
+}
+
 sub _table_alias {
     my $self = shift;
     my ($table_name, $op) = @_;
@@ -653,7 +669,7 @@ DBIx::Lite::ResultSet
 
 =head1 VERSION
 
-version 0.27
+version 0.28
 
 =head1 OVERVIEW
 
@@ -683,6 +699,11 @@ C<AND> operator:
 
     my $rs = $books_rs->search({ year => 2012 })->search({ genre => 'philosophy' });
 
+=head2 clear_search
+
+This method returns a L<DBIx::Lite::ResultSet> object based on the current one
+but with no search conditions.
+
 =head2 select
 
 This method accepts a list of column names to retrieve. The default is C<*>, so
@@ -812,6 +833,11 @@ used, thus allowing to join the same table multiple times using different table
 This method works like L<inner join> except it applies a C<LEFT JOIN> instead of an
 C<INNER JOIN>.
 
+=head2 clear_joins
+
+This method returns a L<DBIx::Lite::ResultSet> object based on the current one
+but with no joins.
+
 =head1 RETRIEVING RESULTS
 
 =head2 all
